@@ -238,19 +238,15 @@ def _print_usb_rx_instructions(info):
     recommended in the remainder of this page are supposed to be executed in the
     virtual machine.
     """.format(name))
-    _print("""
-    Next, install the drivers for the {0}. First download the helper script by
-    running:
-    """.format(name))
 
-    print("    wget https://raw.githubusercontent.com/"
-          "Blockstream/satellite/master/util/tbsdriver.sh\n")
+    _print("Next, install the drivers for the {0} by running:".format(name))
 
-    _item("Then, run the script:")
     print("""
-    bash tbsdriver.sh
+    blocksat-cli deps tbs-drivers
     """)
-    print("Once the script completes the installation, reboot the virtual machine.")
+
+    print("Once the script completes the installation, reboot the virtual "
+          "machine.")
 
     util.prompt_for_enter()
 
@@ -290,6 +286,10 @@ def _print_usb_rx_instructions(info):
     avoid IP address conflicts, use command-line argument `--ip`.
     """)
 
+    _print("""Furthermore, note that this configuration is not persistent across
+    reboots. If you reboot you computer, you need to run `sudo blocksat-cli usb
+    config` again.""")
+
     util.prompt_for_enter()
 
     util._print_sub_header("Launch")
@@ -447,6 +447,20 @@ def _print_next_steps():
     print("You can generate a bitcoin.conf configuration file for Bitcoin Satellite using:")
     print("\n    blocksat-cli btc\n")
 
+
+    print("Next, you can install bitcoin-satellite by running:")
+    print("\n    blocksat-cli deps install --btc\n")
+
+    print("Note that:")
+    _item("The installation works in Ubuntu (18.04, 19.10, and 20.04), Fedora "
+          "(30, 31, and 32), and CentOS (7 and 8).")
+
+    _item("bitcoin-satellite is a fork of bitcoin core, and, as such, it "
+          "installs applications with the same name (i.e., bitcoind, "
+          "bitcoin-cli, bitcoin-qt, and bitcoin-tx). Hence, the installation "
+          "of bitcoin-satellite will fail if you already have bitcoin core "
+          "installed.")
+
     print("For further information, refer to \"doc/bitcoin.md\" or:\n")
     print("https://github.com/Blockstream/satellite/blob/master/doc/bitcoin.md\n")
 
